Learn R Programming

cwm (version 0.0.3)

cwm-package: The package performs cluster weighed modelling assuming normal distribution

Description

It is a R porting of Original Code from Murphy

Arguments

Details

Package:
cwm
Type:
Package
Version:
0.0.1
Date:
2013-03-17

References

Murphy

Examples

Run this code
library(MASS)
data(geyser)
x=geyser[,1]
y=geyser[,2]                            
cwmExample=cwrEm(x,y,nc=2)
print(cwmExample) 

Run the code above in your browser using DataLab